Check class

Constructors

Check()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

range(int i, int min, int max, [String desc = "index"]) → void
type<T>(Value? val, [String? desc]) → void
typeToString<T>(T? value) String