CompilerException class
- Inheritance
-
- Object
- MiniscriptException
- CompilerException
Constructors
- CompilerException([String message = "Syntax Error", Exception? inner])
- CompilerException.withLocation(String context, int lineNum, String message, [Exception? inner])
Properties
Methods
-
description(
) → String -
Get a standard description of this error, including type and location.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited