MiniscriptException class

Implemented types
Implementers

Constructors

MiniscriptException([String message = "Error", Exception? inner])
MiniscriptException.withLocation(String context, int lineNum, String message, [Exception? inner])

Properties

hashCode int
The hash code for this object.
no setterinherited
inner Exception?
getter/setter pair
location SourceLoc?
getter/setter pair
message String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

description() String
Get a standard description of this error, including type and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited