TooManyArgumentsException class

Inheritance

Constructors

TooManyArgumentsException([String message = "Too Many Arguments", Exception? inner])

Properties

hashCode int
The hash code for this object.
no setterinherited
inner Exception?
getter/setter pairinherited
location SourceLoc?
getter/setter pairinherited
message String
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

description() String
Get a standard description of this error, including type and location.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited