hostData property

Object? hostData
getter/setter pair

hostData is just a convenient place for you to attach some arbitrary data to the interpreter. It gets passed through to the context object, so you can access it inside your custom intrinsic functions. Use it for whatever you like (or don't, if you don't feel the need).

Implementation

Object? hostData;