implicitOutput property
implicitOutput: receives the value of expressions entered when in REPL mode. If you're not using the REPL() method, you can safely ignore this.
Implementation
TextOutputMethod? implicitOutput;
implicitOutput: receives the value of expressions entered when in REPL mode. If you're not using the REPL() method, you can safely ignore this.
TextOutputMethod? implicitOutput;