needMoreInput method
Return whether the parser needs more input, for example because we have run out of source code in the middle of an "if" block. This is typically used with REPL for making an interactive console, so you can change the prompt when more input is expected.
Implementation
bool needMoreInput() {
return parser != null && parser!.needMoreInput();
}