restart method

void restart()

Reset the virtual machine to the beginning of the code. Note that this does not reset global variables; it simply clears the stack and jumps to the beginning. Useful in cases where you have a short script you want to run over and over, without recompiling every time.

Implementation

void restart() {
  if (vm != null) vm!.reset();
}