running method

bool running()

Report whether the virtual machine is still running, that is, whether it has not yet reached the end of the program code.

Implementation

bool running() {
  return vm != null && !vm!.done;
}