vm property
vm: the virtual machine this interpreter is running. Most applications will not need to use this, but it's provided for advanced users.
Implementation
tac.Machine? vm;
vm: the virtual machine this interpreter is running. Most applications will not need to use this, but it's provided for advanced users.
tac.Machine? vm;