TextOutputMethod typedef
TextOutputMethod: a function typedef used to return text from the script (e.g. normal output, errors, etc.) to your Dart code.
Implementation
typedef TextOutputMethod = void Function(String output, bool addLineBreak);
TextOutputMethod: a function typedef used to return text from the script (e.g. normal output, errors, etc.) to your Dart code.
typedef TextOutputMethod = void Function(String output, bool addLineBreak);