TokenType enum

Token type enum

Inheritance
Available extensions

Values

unknown → const TokenType
keyword → const TokenType
number → const TokenType
string → const TokenType
identifier → const TokenType
opAssign → const TokenType
opPlus → const TokenType
opMinus → const TokenType
opTimes → const TokenType
opDivide → const TokenType
opMod → const TokenType
opPower → const TokenType
opEqual → const TokenType
opNotEqual → const TokenType
opGreater → const TokenType
opGreatEqual → const TokenType
opLesser → const TokenType
opLessEqual → const TokenType
opAssignPlus → const TokenType
opAssignMinus → const TokenType
opAssignTimes → const TokenType
opAssignDivide → const TokenType
opAssignMod → const TokenType
opAssignPower → const TokenType
lParen → const TokenType
rParen → const TokenType
lSquare → const TokenType
rSquare → const TokenType
lCurly → const TokenType
rCurly → const TokenType
addressOf → const TokenType
comma → const TokenType
dot → const TokenType
colon → const TokenType
comment → const TokenType
eol → const TokenType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TokenType>
A constant List of the values in this enum, in order of their declaration.