outputStack property

List<ParseState?>? outputStack
getter/setter pair

List of open code blocks we're working on (while compiling a function, we push a new one onto this stack, compile to that, and then pop it off when we reach the end of the function).

Implementation

List<ParseState?>? outputStack;