pendingState property

ParseState? pendingState
getter/setter pair

A new parse state that needs to be pushed onto the stack, as soon as we finish with the current line we're working on:

Implementation

ParseState? pendingState;