miniscript_parser/parsing_states library

Classes

BackPatch
BackPatch: represents a place where we need to patch the code to fill in a jump destination (once we figure out where that destination is).
JumpPoint
JumpPoint: represents a place in the code we will need to jump to later (typically, the top of a loop of some sort).
ParseState