BackPatch class

BackPatch: represents a place where we need to patch the code to fill in a jump destination (once we figure out where that destination is).

Constructors

BackPatch({required int lineNum, required String waitingFor})

Properties

hashCode int
The hash code for this object.
no setterinherited
lineNum int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
waitingFor String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited