JumpPoint class

JumpPoint: represents a place in the code we will need to jump to later (typically, the top of a loop of some sort).

Constructors

JumpPoint({required int lineNum, required String keyword})

Properties

hashCode int
The hash code for this object.
no setterinherited
keyword String
getter/setter pair
lineNum int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited