ParseState class

Constructors

ParseState()

Properties

backpatches List<BackPatch>
getter/setter pair
code List<Line>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jumpPoints List<JumpPoint>
getter/setter pair
localOnlyIdentifier String?
getter/setter pair
localOnlyStrict bool
getter/setter pair
nextTempNum int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Line line) → void
addBackpatch(String waitFor) → void
Add the last code line as a backpatch point, to be patched (in rhsA) when we encounter a line with the given waitFor.
addJumpPoint(String jumpKeyword) → void
closeJumpPoint(String keyword) JumpPoint
isJumpTarget(int lineNum) bool
Return whether the given line is a jump target.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String keywordFound, {bool alsoBreak = false, int reservingLines = 0}) → void
Call this method when we've found an 'end' keyword, and want to patch up any jumps that were waiting for that. Patch the matching backpatch (and any after it) to the current code end.
patchIfBlock(bool singleLineIf) → void
Patches up all the branches for a single open if block. That includes the last "else" block, as well as one or more "end if" jumps.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited