pushParamArgument method
Store a parameter argument in preparation for an upcoming call (which should be executed in the context returned by NextCallContext).
Implementation
void pushParamArgument(Value? arg) {
args ??= [];
if (args!.length > 255) {
throw RuntimeException("Argument limit exceeded");
}
args!.add(arg);
}