reset method

void reset([
  1. bool clearVariables = true
])

Reset this context to the first line of code, clearing out any temporary variables, and optionally clearing out all variables.

Implementation

void reset([bool clearVariables = true]) {
  lineNum = 0;
  temps = null;
  if (clearVariables) variables = ValMap();
}