Line class

Constructors

Line(Value? lhs, LineOp op, [Value? rhsA, Value? rhsB])

Properties

comment String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lhs Value?
getter/setter pair
location SourceLoc?
getter/setter pair
op LineOp
getter/setter pair
rhsA Value?
getter/setter pair
rhsB Value?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(Context context) Value?
Evaluate this line and return the value that would be stored into the lhs.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
toStringWithVM([Machine? vm]) String

Operators

operator ==(Object other) bool
The equality operator.
inherited