miniscript_tac/machine library

Classes

Machine
TAC.Machine implements a complete MiniScript virtual machine. It keeps the context stack, keeps track of run time, and provides methods to step, stop, or reset the program.