runTime property
double
get
runTime
Returns the total run time of the machine in seconds.
Implementation
double get runTime {
return stopwatch == null ? 0 : stopwatch!.elapsedMicroseconds / 1000000;
}
Returns the total run time of the machine in seconds.
double get runTime {
return stopwatch == null ? 0 : stopwatch!.elapsedMicroseconds / 1000000;
}