VFunction class

Function: our internal representation of a MiniScript function. This includes its parameters and its code. (It does not include a name -- functions don't actually HAVE names; instead there are named variables whose value may happen to be a function.)

Constructors

VFunction([List<Line>? code])

Properties

code List<Line>?
Function code (compiled down to TAC form)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
parameters List<FunctionParam>
Function parameters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toStringWithVM([Machine? vm]) String

Operators

operator ==(Object other) bool
The equality operator.
inherited