boolValue method

  1. @override
bool boolValue()
override

Get the boolean (truth) value of this Value. By default, we consider any numeric value other than zero to be true. (But subclasses override this with different criteria for strings, lists, and maps.)

Implementation

@override
bool boolValue() {
  // A function value is ALWAYS considered true.
  return true;
}