map<K2, V2> method

  1. @override
Map<K2, V2> map<K2, V2>(
  1. MapEntry<K2, V2> convert(
    1. Value? key,
    2. Value? value
    )
)
override

Returns a new map where all entries of this map are transformed by the given convert function.

Implementation

@override
Map<K2, V2> map<K2, V2>(
  MapEntry<K2, V2> Function(Value? key, Value? value) convert,
) {
  throw UnimplementedError(
    'map<K2, V2>(convert) is not implemented in Dictionary',
  );
}