ValuePair class

ValuePair: used internally when working out whether two maps or lists are equal.

Constructors

ValuePair(Value? a, Value? b)

Properties

a Value?
getter/setter pair
b Value?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override