miniscript_types/value library

Classes

Value
Value: abstract base class for the MiniScript type hierarchy. Defines a number of handy methods that you can call on ANY value (though some of these do nothing for some types).