boolValue method

bool boolValue()

Get the boolean (truth) value of this Value. By default, we consider any numeric value other than zero to be true. (But subclasses override this with different criteria for strings, lists, and maps.)

Implementation

bool boolValue() {
  return intValue() != 0;
}