doubleValue method
Get the numeric value of this Value as a double-precision floating-point number.
Implementation
double doubleValue() {
return 0; // most types don't have a numeric value
}
Get the numeric value of this Value as a double-precision floating-point number.
double doubleValue() {
return 0; // most types don't have a numeric value
}