floatValue method
Get the numeric value of this Value as a single-precision float.
Implementation
double floatValue() {
return doubleValue().toDouble();
}
Get the numeric value of this Value as a single-precision float.
double floatValue() {
return doubleValue().toDouble();
}