hash abstract method
Get a hash value for this Value. Two values that are considered equal will return the same hash value.
Implementation
int hash();
Get a hash value for this Value. Two values that are considered equal will return the same hash value.
int hash();