uintValue method
Get the numeric value of this Value as an unsigned integer.
Implementation
int uintValue() {
return doubleValue().toInt().toUnsigned(32);
}
Get the numeric value of this Value as an unsigned integer.
int uintValue() {
return doubleValue().toInt().toUnsigned(32);
}