val method

Value? val(
  1. Context context
)

Get the current value of this Value in the given context. Basic types evaluate to themselves, but some types (e.g. variable references) may evaluate to something else.

Implementation

Value? val(tac.Context context) {
  return this; // most types evaluate to themselves
}