UnitTest class

Constructors

UnitTest()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

errorIf(bool condition, String err, [int? count, int? length]) → void
errorIfNotEqual(String actual, String expected, [String desc = "Expected {1}, got {0}"]) → void
errorIfNotNull(Object? obj) → void
errorIfNull(Object? obj) → void
reportError(String err) → void
run() → void