TAC.Context keeps track of the runtime environment, including local
variables. Context objects form a linked list via a "parent" reference,
with a new context formed on each function call (this is known as the
call stack).
TAC.Machine implements a complete MiniScript virtual machine. It
keeps the context stack, keeps track of run time, and provides
methods to step, stop, or reset the program.
ValNumber represents a numeric (double-precision floating point) value in MiniScript.
Since we also use numbers to represent boolean values, ValNumber does that job too.
Value: abstract base class for the MiniScript type hierarchy.
Defines a number of handy methods that you can call on ANY
value (though some of these do nothing for some types).
Function: our internal representation of a MiniScript function. This includes
its parameters and its code. (It does not include a name -- functions don't
actually HAVE names; instead there are named variables whose value may happen
to be a function.)