MiniscriptException class
- Implemented types
- Implementers
Constructors
- MiniscriptException([String message = "Error", Exception? inner])
- MiniscriptException.withLocation(String context, int lineNum, String message, [Exception? inner])
Properties
Methods
-
description(
) → String - Get a standard description of this error, including type and location.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited