Lexer class
Properties
- atEnd → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- input ↔ String
-
getter/setter pair
- inputLength ↔ int
-
getter/setter pair
- lineNum ↔ int
-
start at 1, so we report 1-based line numbers
getter/setter pair
-
pending
↔ Queue<
Token> -
getter/setter pair
- position ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dequeue(
) → Token -
isAtWhitespace(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
peek(
) → Token -
skipWhitespaceAndComment(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
check(
Token? tok, TokenType type, [String? text, int lineNum = 0]) → void -
checkLineNum(
int actual, int expected) → void -
commentStartPos(
String source, int startPos) → int -
isIdentifier(
String c) → bool -
isInStringLiteral(
int charPos, String source, [int startPos = 0]) → bool -
isNumeric(
String c) → bool -
isWhitespace(
String c) → bool -
lastToken(
String source) → Token -
runUnitTests(
) → void -
trimComment(
String source) → String