List of open code blocks we're working on (while compiling a function,
we push a new one onto this stack, compile to that, and then pop it
off when we reach the end of the function).
Create a Function with the code we have parsed, for use as
an import. That means, it runs all that code, then at the
end it returns locals so that the caller can get its symbols.
Partially reset, abandoning backpatches, but keeping already-
compiled code. This would be used in a REPL, when the user
may want to reset and continue after a botched loop or function.
Return whether the given source code ends in a token that signifies that
the statement continues on the next line. That includes binary operators,
open brackets or parentheses, etc.