ParseState class
Methods
add (Line line )
→ void
addBackpatch (String waitFor )
→ void
Add the last code line as a backpatch point, to be patched
(in rhsA) when we encounter a line with the given waitFor.
addJumpPoint (String jumpKeyword )
→ void
closeJumpPoint (String keyword )
→ JumpPoint
isJumpTarget (int lineNum )
→ bool
Return whether the given line is a jump target.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch (String keywordFound , {bool alsoBreak = false , int reservingLines = 0 })
→ void
Call this method when we've found an 'end' keyword, and want
to patch up any jumps that were waiting for that. Patch the
matching backpatch (and any after it) to the current code end.
patchIfBlock (bool singleLineIf )
→ void
Patches up all the branches for a single open if block. That includes
the last "else" block, as well as one or more "end if" jumps.
toString ()
→ String
A string representation of this object.
inherited