addBackpatch method
Add the last code line as a backpatch point, to be patched (in rhsA) when we encounter a line with the given waitFor.
Implementation
void addBackpatch(String waitFor) {
backpatches.add(BackPatch(lineNum: code.length - 1, waitingFor: waitFor));
}