miniscript_tac/context library
Classes
- Context
- TAC.Context keeps track of the runtime environment, including local variables. Context objects form a linked list via a "parent" reference, with a new context formed on each function call (this is known as the call stack).