LineOp enum
Values
- noop → const LineOp
- assignA → const LineOp
- assignImplicit → const LineOp
- aPlusB → const LineOp
- aMinusB → const LineOp
- aTimesB → const LineOp
- aDividedByB → const LineOp
- aModB → const LineOp
- aPowB → const LineOp
- aEqualB → const LineOp
- aNotEqualB → const LineOp
- aGreaterThanB → const LineOp
- aGreatOrEqualB → const LineOp
- aLessThanB → const LineOp
- aLessOrEqualB → const LineOp
- aIsaB → const LineOp
- aAndB → const LineOp
- aOrB → const LineOp
- bindAssignA → const LineOp
- copyA → const LineOp
- newA → const LineOp
- notA → const LineOp
- gotoA → const LineOp
- gotoAifB → const LineOp
- gotoAifTrulyB → const LineOp
- gotoAifNotB → const LineOp
- pushParam → const LineOp
- callFunctionA → const LineOp
- callIntrinsicA → const LineOp
- returnA → const LineOp
- elemBofA → const LineOp
- elemBofIterA → const LineOp
- lengthOfA → const LineOp
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited