miniscript_tac/tac library
Classes
- Context
- TAC.Context keeps track of the runtime environment, including local variables. Context objects form a linked list via a "parent" reference, with a new context formed on each function call (this is known as the call stack).
- Line
- Machine
- TAC.Machine implements a complete MiniScript virtual machine. It keeps the context stack, keeps track of run time, and provides methods to step, stop, or reset the program.