valWithMap method
This version of Val is like the one above, but also returns (via the output parameter) the ValMap the value was found in, which could be several steps up the __isa chain.
Implementation
Value? valWithMap(tac.Context context, ValuePointer<ValMap> valueFoundIn) {
valueFoundIn.value = null;
return this;
}