TempValString class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- next ↔ TempValString?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ String
-
getter/setter pairinherited
Methods
-
boolValue(
) → bool -
Get the boolean (truth) value of this Value. By default, we consider
any numeric value other than zero to be true. (But subclasses override
this with different criteria for strings, lists, and maps.)
inherited
-
canSetElem(
) → bool -
Can we set elements within this value? (I.e., is it a list or map?)
inherited
-
codeForm(
Machine? vm, {int recursionLimit = -1}) → String -
Get this value in the form of a MiniScript literal.
inherited
-
doubleValue(
) → double -
Get the numeric value of this Value as a double-precision floating-point number.
inherited
-
equality(
Value? rhs) → double -
Check whether this Value is equal to another Value.
inherited
-
floatValue(
) → double -
Get the numeric value of this Value as a single-precision float.
inherited
-
fullEval(
Context context) → Value? -
Similar to Val, but recurses into the sub-values contained by this
value (if it happens to be a container, such as a list or map).
inherited
-
getElem(
Value index) → Value -
inherited
-
hash(
) → int -
Get a hash value for this Value. Two values that are considered
equal will return the same hash value.
inherited
-
intValue(
) → int -
Get the numeric value of this Value as an integer.
inherited
-
isA(
Value? type, Machine vm) → bool -
Return whether this value is the given type (or some subclass thereof)
in the context of the given virtual machine.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recursiveEqual(
Value rhs) → bool -
Compare lhs and rhs for equality, in a way that traverses down
the tree when it finds a list or map. For any other type, this
just calls through to the regular Equality method.
inherited
-
recursiveHash(
) → int -
Hash function that works correctly with nested lists and maps.
inherited
-
setElem(
Value? index, Value? value) → void -
Set an element associated with the given index within this Value.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toStringWithVM(
[Machine? vm]) → String -
inherited
-
uintValue(
) → int -
Get the numeric value of this Value as an unsigned integer.
inherited
-
val(
Context context) → Value? -
Get the current value of this Value in the given context. Basic types
evaluate to themselves, but some types (e.g. variable references) may
evaluate to something else.
inherited
-
valWithMap(
Context context, ValuePointer< ValMap> valueFoundIn) → Value? -
This version of Val is like the one above, but also returns
(via the output parameter) the ValMap the value was found in,
which could be several steps up the __isa chain.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
get(
String s) → TempValString -
release(
TempValString temp) → void